@@ -1,5 +1,6 @@
 # coding: utf-8
 
+from .about_window import AboutWindow
 from .indexurl_manager import IndexUrlManagerWindow
 from .messagebox import MessageBox
 from .package_download import PackageDownloadWindow
@@ -7,6 +8,7 @@ from .package_manager import PackageManagerWindow
 from .pyinstaller_tool import PyinstallerToolWindow
 
 __all__ = [
+    "AboutWindow",
     "IndexUrlManagerWindow",
     "MessageBox",
     "PackageDownloadWindow",
