@@ -1,6 +1,6 @@
 # coding: utf-8
 
-from .abstract_config import config_root, generate_respath
+from .abstract_config import config_root, generate_respath, themes_root
 from .indexurl_manager import IndexManagerConfig
 from .main_entrance import MainEntranceConfig
 from .package_download import PackageDownloadConfig
@@ -10,6 +10,7 @@ from .pyinstaller_tool import PyiConfigure, PyinstallerToolConfig
 __all__ = [
     "config_root",
     "generate_respath",
+    "themes_root",
     "IndexManagerConfig",
     "MainEntranceConfig",
     "PackageDownloadConfig",
