@@ -1,8 +1,6 @@
 # coding: utf-8
 
 from .main import (
-    QThreadModel,
-    ThreadRepo,
     check_index_url,
     check_py_path,
     clean_index_urls,
@@ -14,8 +12,6 @@ from .main import (
 )
 
 __all__ = [
-    "QThreadModel",
-    "ThreadRepo",
     "check_index_url",
     "check_py_path",
     "clean_index_urls",
